@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2007 Lovely Systems and Contributors.
+# Copyright (c) 2007 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: buildouthttp.py 112794 2010-05-28 11:41:12Z dobe $
+$Id: buildouthttp.py 115983 2010-08-28 06:52:14Z dobe $
 """
 
 import urllib2
@@ -32,11 +32,15 @@ def get_github_credentials():
     """returns the credentials for the local git installation by using
     git config"""
 
-    pipe = subprocess.Popen("git config github.token",
-                            shell=True,
-                            stdout=subprocess.PIPE).stdout
-    token = pipe.readline().strip()
-    pipe.close()
+    p = subprocess.Popen("gitx config github.token",
+                         shell=True,
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.PIPE)
+    rc = p.wait()
+    if rc:
+        # failure to get config, so return silently
+        return None
+    token = p.stdout.readline().strip()
     pipe = subprocess.Popen("git config github.user",
                             shell=True,
                             stdout=subprocess.PIPE).stdout
